@@ -3,7 +3,8 @@
 library(Distance)
 library(testthat)
 
-par.tol <- 1e-6
+par.tol <- 1e-5
+p.tol <- 1e-5
 lnl.tol <- 1e-4
 
 context("Point transects")
@@ -19,7 +20,7 @@ test_that("ptexample.distance from mrds gives same results",{
 
   expect_that(xx$ddf$par,equals(2.283007,tol=par.tol))
   expect_that(xx$ddf$lnl,equals(-458.5701,tol=lnl.tol))
-  expect_that(summary(xx$ddf)$average.p,equals(0.1644288,tol=par.tol))
+  expect_that(summary(xx$ddf)$average.p,equals(0.1644288,tol=p.tol))
 
 })
 
@@ -37,6 +38,6 @@ test_that("ptexample.single from mrds gives same results -- binned",{
 
   expect_that(xx$ddf$par,equals(3.397266,tol=par.tol))
   expect_that(xx$ddf$lnl,equals(-687.7673,tol=lnl.tol))
-  expect_that(summary(xx$ddf)$average.p,equals(0.1779269,tol=par.tol))
+  expect_that(summary(xx$ddf)$average.p,equals(0.1779359,tol=p.tol))
 
 })
